package image

import (
	"context"

	"github.com/aquasecurity/trivy/pkg/report"
	v1 "k8s.io/api/apps/v1"
	batchv1 "k8s.io/api/batch/v1"
)

type KubernetesClient interface {
	ListDeployments(ctx context.Context) ([]v1.Deployment, error)
	ListStatefulSets(ctx context.Context) ([]v1.StatefulSet, error)
	ListDaemonSets(ctx context.Context) ([]v1.DaemonSet, error)
	ListCronJobs(ctx context.Context) ([]batchv1.CronJob, error)
}

type TrivyClient interface {
	ScanImage(ctx context.Context, image string, cacheDir string) (*report.Report, error)
	UpdateDatabase(ctx context.Context, cacheDir string) error
}
